/*
	ChatServer object that creates registry and binds the Service

	Author : Dattaraj J. Rao		dattarajrao@yahoo.com
*/

import java.rmi.*;
import java.rmi.registry.*;

import java.util.*;

public class ChatServer
{
	public static void main(String[] args) 
	{
		// Set port and name of server //
		String SERVER_NAME;
		int PORT;

		if(args.length==2)
		{
			SERVER_NAME=args[0];
			try
			{
				PORT=Integer.parseInt(args[1]);
			}
			catch(Exception e)
			{
				PORT=900;
			}
		}
		else
		{
			SERVER_NAME="localhost";
			PORT=900;
		}

		// Set the system properties //
		String codebase=System.getProperty("java.rmi.server.codebase");
		if(codebase==null)
		{
			Properties env=System.getProperties();
			env.put("java.rmi.server.codebase","http://localhost/Chat/");
			System.setProperties(env);
		}

		System.setSecurityManager(new RMISecurityManager());

		// Initiate rmiregistry if not started //
		Registry registry=null;
		try
		{
			registry=LocateRegistry.getRegistry(PORT);
			registry.list();
		}
		catch(Exception e)
		{
			registry=null;
		}

		if(registry==null)
		{
			try
			{
				registry=LocateRegistry.createRegistry(PORT);
			}
			catch(Exception e)
			{
				System.out.println(e);
				System.exit(0);
			}
		}

		// Create service and bind it //
		try
		{
			ChatService service=new ChatService();
			registry.rebind("ChatService",service);

			System.out.println("Service Started");
		}
		catch(Exception e)
		{
			System.out.println(e);
		}
	}
}